==> qtjambi-remoteobjects-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiRemoteObjects/QRemoteObjectHostBase_RemoteObjectNameFilter_shell.cpp <==
#include "QRemoteObjectHostBase_RemoteObjectNameFilter_shell.h"
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>
// emitting (writeShellConstructor)
void deleter_QRemoteObjectHostBase_RemoteObjectNameFilter(void *ptr,bool) { delete reinterpret_cast<QRemoteObjectHostBase_RemoteObjectNameFilter_shell*>(ptr); }


QRemoteObjectHostBase_RemoteObjectNameFilter_shell::QRemoteObjectHostBase_RemoteObjectNameFilter_shell()
    : FunctionalBase()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QRemoteObjectHostBase_RemoteObjectNameFilter_shell::QRemoteObjectHostBase_RemoteObjectNameFilter_shell()")
    QRemoteObjectHostBase_RemoteObjectNameFilter_shell::__shell()->constructed(typeid(QRemoteObjectHostBase::RemoteObjectNameFilter));
}

// emitting (writeShellDestructor)
QRemoteObjectHostBase_RemoteObjectNameFilter_shell::~QRemoteObjectHostBase_RemoteObjectNameFilter_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QRemoteObjectHostBase_RemoteObjectNameFilter_shell::~QRemoteObjectHostBase_RemoteObjectNameFilter_shell()", QRemoteObjectHostBase_RemoteObjectNameFilter_shell::__shell())
    QRemoteObjectHostBase_RemoteObjectNameFilter_shell::__shell()->destructed(typeid(QRemoteObjectHostBase::RemoteObjectNameFilter));
}

// construct QRemoteObjectHostBase_RemoteObjectNameFilter_shell
void __qt_construct_QRemoteObjectHostBase_RemoteObjectNameFilter(void* __qtjambi_ptr, JNIEnv*, jobject, jvalue*, bool)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QRemoteObjectHostBase::RemoteObjectNameFilter")
    new (__qtjambi_ptr) QRemoteObjectHostBase_RemoteObjectNameFilter_shell();
}
// destruct QRemoteObjectHostBase_RemoteObjectNameFilter_shell
void __qt_destruct_QRemoteObjectHostBase_RemoteObjectNameFilter(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QRemoteObjectHostBase::RemoteObjectNameFilter")
    reinterpret_cast<QRemoteObjectHostBase_RemoteObjectNameFilter_shell*>(ptr)->~QRemoteObjectHostBase_RemoteObjectNameFilter_shell();
}

void QRemoteObjectHostBase_RemoteObjectNameFilter_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QRemoteObjectHostBase_RemoteObjectNameFilter_shell*>(ptr)->QRemoteObjectHostBase_RemoteObjectNameFilter_shell::__shell()->tryDeleteShell(typeid(QRemoteObjectHostBase::RemoteObjectNameFilter));
}

QtJambiShell* QRemoteObjectHostBase_RemoteObjectNameFilter_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QRemoteObjectHostBase_RemoteObjectNameFilter_shell) ); }

QRemoteObjectHostBase_RemoteObjectNameFilter_shell::Functor::Functor(QRemoteObjectHostBase_RemoteObjectNameFilter_shell& functional) : FunctorBase(typeid(QRemoteObjectHostBase::RemoteObjectNameFilter), functional) {}

QRemoteObjectHostBase_RemoteObjectNameFilter_shell::Functor::Functor(const Functor& functor) : FunctorBase(functor) {}

QRemoteObjectHostBase_RemoteObjectNameFilter_shell::Functor::~Functor() {}

bool  QRemoteObjectHostBase_RemoteObjectNameFilter_shell::Functor::operator()(const QString& arg__1, const QString& arg__2)
{
    bool __qt_return_value = false;
    if (jmethodID method_id = javaMethod()) {
        if (JniEnvironment env{400}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if (jobject __java_this = getJavaObjectLocalRef(env)) {
                    jstring __java_arg__1 = qtjambi_cast<jstring>(env, arg__1);
                    jstring __java_arg__2 = qtjambi_cast<jstring>(env, arg__2);
                    jboolean __java_return_value = env->CallBooleanMethod(__java_this, method_id, __java_arg__1, __java_arg__2);
                    JavaException::check(env QTJAMBI_STACKTRACEINFO );
                    bool __qt_return_value_tmp = static_cast<bool>(__java_return_value);
                    __qt_return_value = __qt_return_value_tmp;
                }
            } QTJAMBI_CATCH(const JavaException& exn) {
                __qj_exnhandler.handle(env, exn, "QRemoteObjectHostBase::RemoteObjectNameFilter");
            } QTJAMBI_TRY_END
        }
    }
    return __qt_return_value;
}

void QRemoteObjectHostBase_RemoteObjectNameFilter_shell::getFunctional(JNIEnv *, void* result)
{
    *reinterpret_cast<QRemoteObjectHostBase::RemoteObjectNameFilter*>(result) = Functor(*this);
}

jobject QRemoteObjectHostBase_RemoteObjectNameFilter_shell::resolveFunctional(JNIEnv * env, const void* functionPtr, bool* ok)
{
    if(functionPtr){
        const QRemoteObjectHostBase::RemoteObjectNameFilter& function = *reinterpret_cast<const QRemoteObjectHostBase::RemoteObjectNameFilter*>(functionPtr);
        if(const QRemoteObjectHostBase_RemoteObjectNameFilter_shell::Functor* functor = function.target<QRemoteObjectHostBase_RemoteObjectNameFilter_shell::Functor>()){
            if(ok)
                *ok = true;
            return functor->getJavaObjectLocalRef(env);
        }
        if(ok)
            *ok = !function;
    }
    return nullptr;
}

extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QRemoteObjectHostBase_00024RemoteObjectNameFilter_00024Impl_00024ConcreteWrapper_test__Ljava_lang_String_2Ljava_lang_String_2)
(JNIEnv *__jni_env, jobject __this, jstring arg__1, jstring arg__2)
{
    QTJAMBI_NATIVE_METHOD_CALL("RemoteObjectNameFilter(...)")
    QtJambiScope __qtjambi_scope(__jni_env, __this);
    Q_UNUSED(__qtjambi_scope)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QRemoteObjectHostBase::RemoteObjectNameFilter* function = QtJambiAPI::convertJavaInterfaceToNative<QRemoteObjectHostBase::RemoteObjectNameFilter>(__jni_env, __this);
        QtJambiAPI::checkNullPointer(__jni_env, function);
        QString  __qt_arg__1 = qtjambi_cast<QString>(__jni_env, arg__1);
        QString  __qt_arg__2 = qtjambi_cast<QString>(__jni_env, arg__2);
__java_return_value = (*function)(__qt_arg__1, __qt_arg__2);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QRemoteObjectHostBase_00024RemoteObjectNameFilter_00024Impl_initialize_1native)
(JNIEnv *__jni_env, jclass __jni_class, jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QRemoteObjectHostBase_RemoteObjectNameFilter_shell")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QRemoteObjectHostBase_RemoteObjectNameFilter, sizeof(QRemoteObjectHostBase_RemoteObjectNameFilter_shell), typeid(QRemoteObjectHostBase::RemoteObjectNameFilter), &deleter_QRemoteObjectHostBase_RemoteObjectNameFilter);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
}

void initialize_meta_info_QRemoteObjectHostBase_RemoteObjectNameFilter(){
    using namespace RegistryAPI;
    registerFunctionalTypeInfo<QRemoteObjectHostBase::RemoteObjectNameFilter, QRemoteObjectHostBase_RemoteObjectNameFilter_shell>("QRemoteObjectHostBase::RemoteObjectNameFilter", "io/qt/remoteobjects/QRemoteObjectHostBase$RemoteObjectNameFilter",
                              &deleter_QRemoteObjectHostBase_RemoteObjectNameFilter,
                              &__qt_destruct_QRemoteObjectHostBase_RemoteObjectNameFilter,
                              {ConstructorInfo(&__qt_construct_QRemoteObjectHostBase_RemoteObjectNameFilter, nullptr)},
                              {FunctionInfo("test", "(Ljava/lang/String;Ljava/lang/String;)Z", FunctionInfo::Abstract)});
}

==> qtjambi-remoteobjects-debuginfo-linux-x64-6.6.2.jar: sources/QtJambiRemoteObjects/QRemoteObjectHostBase_RemoteObjectNameFilter_shell.cpp <==
#include "QRemoteObjectHostBase_RemoteObjectNameFilter_shell.h"
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>
// emitting (writeShellConstructor)
void deleter_QRemoteObjectHostBase_RemoteObjectNameFilter(void *ptr,bool) { delete reinterpret_cast<QRemoteObjectHostBase_RemoteObjectNameFilter_shell*>(ptr); }


QRemoteObjectHostBase_RemoteObjectNameFilter_shell::QRemoteObjectHostBase_RemoteObjectNameFilter_shell()
    : FunctionalBase()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QRemoteObjectHostBase_RemoteObjectNameFilter_shell::QRemoteObjectHostBase_RemoteObjectNameFilter_shell()")
    QRemoteObjectHostBase_RemoteObjectNameFilter_shell::__shell()->constructed(typeid(QRemoteObjectHostBase::RemoteObjectNameFilter));
}

// emitting (writeShellDestructor)
QRemoteObjectHostBase_RemoteObjectNameFilter_shell::~QRemoteObjectHostBase_RemoteObjectNameFilter_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QRemoteObjectHostBase_RemoteObjectNameFilter_shell::~QRemoteObjectHostBase_RemoteObjectNameFilter_shell()", QRemoteObjectHostBase_RemoteObjectNameFilter_shell::__shell())
    QRemoteObjectHostBase_RemoteObjectNameFilter_shell::__shell()->destructed(typeid(QRemoteObjectHostBase::RemoteObjectNameFilter));
}

// construct QRemoteObjectHostBase_RemoteObjectNameFilter_shell
void __qt_construct_QRemoteObjectHostBase_RemoteObjectNameFilter(void* __qtjambi_ptr, JNIEnv*, jobject, jvalue*, bool)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QRemoteObjectHostBase::RemoteObjectNameFilter")
    new (__qtjambi_ptr) QRemoteObjectHostBase_RemoteObjectNameFilter_shell();
}
// destruct QRemoteObjectHostBase_RemoteObjectNameFilter_shell
void __qt_destruct_QRemoteObjectHostBase_RemoteObjectNameFilter(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QRemoteObjectHostBase::RemoteObjectNameFilter")
    reinterpret_cast<QRemoteObjectHostBase_RemoteObjectNameFilter_shell*>(ptr)->~QRemoteObjectHostBase_RemoteObjectNameFilter_shell();
}

void QRemoteObjectHostBase_RemoteObjectNameFilter_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QRemoteObjectHostBase_RemoteObjectNameFilter_shell*>(ptr)->QRemoteObjectHostBase_RemoteObjectNameFilter_shell::__shell()->tryDeleteShell(typeid(QRemoteObjectHostBase::RemoteObjectNameFilter));
}

QtJambiShell* QRemoteObjectHostBase_RemoteObjectNameFilter_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QRemoteObjectHostBase_RemoteObjectNameFilter_shell) ); }

QRemoteObjectHostBase_RemoteObjectNameFilter_shell::Functor::Functor(QRemoteObjectHostBase_RemoteObjectNameFilter_shell& functional) : FunctorBase(typeid(QRemoteObjectHostBase::RemoteObjectNameFilter), functional) {}

QRemoteObjectHostBase_RemoteObjectNameFilter_shell::Functor::Functor(const Functor& functor) : FunctorBase(functor) {}

QRemoteObjectHostBase_RemoteObjectNameFilter_shell::Functor::~Functor() {}

bool  QRemoteObjectHostBase_RemoteObjectNameFilter_shell::Functor::operator()(QStringView arg__1, QStringView arg__2)
{
    bool __qt_return_value = false;
    if (jmethodID method_id = javaMethod()) {
        if (JniEnvironment env{400}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if (jobject __java_this = getJavaObjectLocalRef(env)) {
                    jstring __java_arg__1 = qtjambi_cast<jstring>(env, arg__1);
                    jstring __java_arg__2 = qtjambi_cast<jstring>(env, arg__2);
                    jboolean __java_return_value = env->CallBooleanMethod(__java_this, method_id, __java_arg__1, __java_arg__2);
                    JavaException::check(env QTJAMBI_STACKTRACEINFO );
                    bool __qt_return_value_tmp = static_cast<bool>(__java_return_value);
                    __qt_return_value = __qt_return_value_tmp;
                }
            } QTJAMBI_CATCH(const JavaException& exn) {
                __qj_exnhandler.handle(env, exn, "QRemoteObjectHostBase::RemoteObjectNameFilter");
            } QTJAMBI_TRY_END
        }
    }
    return __qt_return_value;
}

void QRemoteObjectHostBase_RemoteObjectNameFilter_shell::getFunctional(JNIEnv *, void* result)
{
    *reinterpret_cast<QRemoteObjectHostBase::RemoteObjectNameFilter*>(result) = Functor(*this);
}

jobject QRemoteObjectHostBase_RemoteObjectNameFilter_shell::resolveFunctional(JNIEnv * env, const void* functionPtr, bool* ok)
{
    if(functionPtr){
        const QRemoteObjectHostBase::RemoteObjectNameFilter& function = *reinterpret_cast<const QRemoteObjectHostBase::RemoteObjectNameFilter*>(functionPtr);
        if(const QRemoteObjectHostBase_RemoteObjectNameFilter_shell::Functor* functor = function.target<QRemoteObjectHostBase_RemoteObjectNameFilter_shell::Functor>()){
            if(ok)
                *ok = true;
            return functor->getJavaObjectLocalRef(env);
        }
        if(ok)
            *ok = !function;
    }
    return nullptr;
}

extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QRemoteObjectHostBase_00024RemoteObjectNameFilter_00024Impl_00024ConcreteWrapper_test__Ljava_lang_String_2Ljava_lang_String_2)
(JNIEnv *__jni_env, jobject __this, jstring arg__1, jstring arg__2)
{
    QTJAMBI_NATIVE_METHOD_CALL("RemoteObjectNameFilter(...)")
    QtJambiScope __qtjambi_scope(__jni_env, __this);
    Q_UNUSED(__qtjambi_scope)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QRemoteObjectHostBase::RemoteObjectNameFilter* function = QtJambiAPI::convertJavaInterfaceToNative<QRemoteObjectHostBase::RemoteObjectNameFilter>(__jni_env, __this);
        QtJambiAPI::checkNullPointer(__jni_env, function);
        QStringView  __qt_arg__1 = qtjambi_cast<QStringView>(__jni_env, __qtjambi_scope, arg__1);
        QStringView  __qt_arg__2 = qtjambi_cast<QStringView>(__jni_env, __qtjambi_scope, arg__2);
__java_return_value = (*function)(__qt_arg__1, __qt_arg__2);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QRemoteObjectHostBase_00024RemoteObjectNameFilter_00024Impl_initialize_1native)
(JNIEnv *__jni_env, jclass __jni_class, jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QRemoteObjectHostBase_RemoteObjectNameFilter_shell")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QRemoteObjectHostBase_RemoteObjectNameFilter, sizeof(QRemoteObjectHostBase_RemoteObjectNameFilter_shell), typeid(QRemoteObjectHostBase::RemoteObjectNameFilter), &deleter_QRemoteObjectHostBase_RemoteObjectNameFilter);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
}

void initialize_meta_info_QRemoteObjectHostBase_RemoteObjectNameFilter(){
    using namespace RegistryAPI;
    registerFunctionalTypeInfo<QRemoteObjectHostBase::RemoteObjectNameFilter, QRemoteObjectHostBase_RemoteObjectNameFilter_shell>("QRemoteObjectHostBase::RemoteObjectNameFilter", "io/qt/remoteobjects/QRemoteObjectHostBase$RemoteObjectNameFilter",
                              &deleter_QRemoteObjectHostBase_RemoteObjectNameFilter,
                              &__qt_destruct_QRemoteObjectHostBase_RemoteObjectNameFilter,
                              {ConstructorInfo(&__qt_construct_QRemoteObjectHostBase_RemoteObjectNameFilter, nullptr)},
                              {FunctionInfo("test", "(Ljava/lang/String;Ljava/lang/String;)Z", FunctionInfo::Abstract)});
}
